#[repr(u8)]pub enum Operation {
Sentinel = 0,
M = 1,
Eq = 2,
X = 3,
I = 4,
D = 5,
}Expand description
A match/mismatch, insertion, or deletion operation.
When aligning q against r, this represents the edit operations to get from r to q.
Variants
Sentinel = 0
Placeholder variant.
M = 1
Match or mismatch.
This is a diagonal transition in the DP matrix with |q| + 1 rows and |r| + 1 columns.
Eq = 2
Match.
X = 3
Mismatch.
I = 4
Insertion.
When aligning sequences q against r, this is a gap in r.
This is a row transition in the DP matrix with |q| + 1 rows and |r| + 1 columns.
D = 5
Deletion.
When aligning sequences q against r, this is a gap in q.
This is a column transition in the DP matrix with |q| + 1 rows and |r| + 1 columns.